@@ -17,14 +17,20 @@ del hard_dependencies, dependency, missing_dependencies
 # datascientists version
 from datascientists._version import __version__
 
+# Hypothesis Testing
+from datascientists.core.hypothesisTesting import *
+
 # Preprocessing
 from datascientists.core.preprocessing import *
 
 # Regression
 from datascientists.core.regression import *
 
-# Hypothesis Testing
-from datascientists.core.hypothesisTesting import *
+# Simulation
+from datascientists.core.simulation import *
+
+# Statistical Test
+from datascientists.core.statisticalTest import *
 
 # module level doc-string
 __doc__ = f"""
