@@ -1,5 +1,5 @@
 """
-This module is imported from the ds_zacks package __init__.py file
+This module is imported from the datascientists package __init__.py file
 in order to ensure that the core.config options registered here will
 be available as soon as the user loads the package. if register_option
 is invoked inside specific modules, they will not be registered until that
@@ -12,4 +12,4 @@ module is imported, register them here rather than in the module.
 
 import warnings
 
-import ds_zacks._config.config as cf
+import datascientists._config.config as cf
